==> enx_uikit_flutter-1.7.0.tar.gz: lib/widgets/confirmation_screen.dart <==
import 'dart:io';

import 'package:enx_flutter_plugin/enx_player_widget.dart';
import 'package:enx_uikit_flutter/screens/setting_ui.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:get/get_navigation/src/routes/transitions_type.dart';

import '../controller/enx_controller.dart';
import '../utilities/color.dart';

Widget confirmationScreen(context, EnxController obj) {
  return Container(
    color: Colors.white,
    child: Column(
      children: [
        Visibility(
          visible: false,
          child: AppBar(
            automaticallyImplyLeading: false,
            title: const Text('Video Preview',style: TextStyle(color: Colors.black,fontWeight: FontWeight.w500,fontSize: 17),),
            backgroundColor: Colors.white,
          ),
        ),
        MediaQuery.of(context).orientation==Orientation.portrait?
        Stack(
          alignment: Alignment.bottomCenter,
          children: [
            SizedBox(
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height-30,
          child:obj.isSelected[1]||obj.isSelected[2]?Container(color: Colors.grey,child: const Icon(Icons.videocam_off_outlined),) :Platform.isAndroid
              ? EnxPlayerWidget(
            0,
            local: true,
            zMediaOverlay: false,
            height: MediaQuery.of(context).size.height ~/ 1.6,
          )
              : AspectRatio(
              aspectRatio: 3 / 2,
              child: EnxPlayerWidget(
                0,
                local: true,
                height: MediaQuery.of(context).size.height ~/ 1.6,
                width: MediaQuery.of(context).size.width.toInt(),
              )),
        ),
          Padding(
            padding: const EdgeInsets.all(12.0),
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15.0),
              ),
            elevation: 15,
              child: Padding(
                padding: const EdgeInsets.only(left:20,top: 28.0,bottom: 28,right: 20),
                child: Wrap(
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        ToggleButtons(
                          children: <Widget>[
                            obj.isSelected.first?Icon(Icons.mic_off_outlined):Icon(Icons.mic_none_outlined),
                            obj.isSelected[1]? Icon(Icons.videocam_off_outlined):Icon(Icons.video_call_outlined),
                             const Padding(
                              padding: EdgeInsets.all(8.0),
                              child:Row(
                                children: [
                                  Icon(Icons.mic_none_outlined),
                                  Text("Audio Only"),
                                ],
                              ),
                            ),

                          ],
                          isSelected: obj.isSelected,
                          onPressed: (int index) {
                            if(index==2) {
                              obj.isSelect.value[index] = !obj.isSelect.value[index];
                              if(obj.isVideoSelected.value) {
                                obj.isSelect.value[1]=obj.isSelect.value[1];
                              } else {
                                obj.isSelect.value[1]=!obj.isSelect.value[1];
                              }

                            }
                            else{
                              if(obj.isSelect[2]) {
                                if(obj.isSelect[1]) {
                                  obj.isSelect.value[1] = obj.isSelect.value[1];
                                }
                              } else {
                                if(index==1){
                                  obj.isVideoSelected.value=!obj.isVideoSelected.value;
                                }
                                obj.isSelect.value[index] = !obj.isSelect.value[index];
                              }
                            }
                            obj.isSelect.refresh();
                          },
                          // region example 1
                          color: Colors.grey,
                          selectedColor: CustomColors.themeColor,
                          // endregion
                          // region example 2
                          borderColor: Colors.grey,
                          selectedBorderColor: CustomColors.themeColor,

                           constraints: BoxConstraints(
                              minHeight: 40, minWidth: MediaQuery.of(context).size.width/4),
                          // endregion
                        ),
                        // GestureDetector(
                        //   onTap: (){
                        //     obj.settingListItem();
                        //     Get.to(() => SettingScreen(obj),
                        //         transition: Transition.leftToRight,
                        //         duration: const Duration(seconds: 1));
                        //   // obj.isSetting.value=!obj.isSetting.value;
                        //     Fluttertoast.showToast(
                        //         msg: "Setting",
                        //         toastLength: Toast.LENGTH_SHORT,
                        //         gravity: ToastGravity.CENTER,
                        //         backgroundColor: Colors.red,
                        //         textColor: Colors.white,
                        //         fontSize: 16.0);
                        //   },
                        //   child: Container(
                        //     decoration: BoxDecoration(
                        //         border: Border.all(color: Colors.grey),),
                        //       child: const Padding(
                        //         padding: EdgeInsets.all(8.0),
                        //         child: Icon(Icons.settings_outlined),
                        //       )),
                        // ),
                      ],
                    ),
                   /* Padding(
                      padding:  EdgeInsets.only(left:MediaQuery.of(context).size.width/12,right: MediaQuery.of(context).size.width/10),
                      child: SwitchListTile( //switch at left side of label
                          value: obj.audioOnly,
                          controlAffinity: ListTileControlAffinity.trailing,
                          onChanged: (bool value){
                            obj.isAudioOnly.value=!obj.isAudioOnly.value;
                            obj.isAudioOnly.refresh();
                          },
                          title:  Text("Join as a audio call only",style: TextStyle(fontSize: 15,color: Colors.black,fontWeight: FontWeight.w400),)
                      ),
                    ),*/
                    Padding(
                      padding: const EdgeInsets.only(top:20.0),
                      child: Center(
                        child: DecoratedBox(
                         decoration: BoxDecoration(
                           gradient: const LinearGradient(
                                   colors: [
                                     Colors.pinkAccent,
                                     Colors.pink,
                                     CustomColors.themeColor,
                                     ]),
                            borderRadius: BorderRadius.circular(15),),
                          child: ElevatedButton(
                            child: const Text("Join Now",style: TextStyle(color: Colors.white,fontWeight: FontWeight.w400,fontSize: 15),),
                            style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.transparent,
                                disabledForegroundColor: Colors.transparent.withOpacity(0.38),
                                disabledBackgroundColor: Colors.transparent.withOpacity(0.12),
                                shadowColor: Colors.transparent,
                                elevation: 5,
                                shape:RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(15.0),) ,
                                fixedSize: Size(MediaQuery.of(context).size.width / 2, 50)),
                            onPressed: () {
                              obj.isConfirmation.value=true;
                              obj.configureRoom();
                            },
                          ),
                        ),
                      ),
                    ),
                  ]
                ),
              ),
            ),
          ),
          ],):
          Row(
           crossAxisAlignment: CrossAxisAlignment.center,
            children:[
            SizedBox(
          width: MediaQuery.of(context).size.width/2,
          height: MediaQuery.of(context).size.height-35,
          child:obj.isSelected[1]||obj.isSelected[2]?Container(color: Colors.grey,child: const Icon(Icons.videocam_off_outlined),) :Platform.isAndroid
              ? EnxPlayerWidget(
            0,
            local: true,
            zMediaOverlay: false,
            height: MediaQuery.of(context).size.height ~/ 1.6,
          )
              : AspectRatio(
              aspectRatio: 3 / 2,
              child: EnxPlayerWidget(
                0,
                local: true,
                height: MediaQuery.of(context).size.height ~/ 1.6,
                width: MediaQuery.of(context).size.width.toInt(),
              )),
        ),
              SizedBox(
          width:MediaQuery.of(context).size.width/2,
            child: Wrap(
              alignment: WrapAlignment.center,
              children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  ToggleButtons(

                    children: <Widget>[
                      obj.isSelected.first?Icon(Icons.mic_off_outlined):Icon(Icons.mic_none_outlined),
                      obj.isSelected[1]? Icon(Icons.videocam_off_outlined):Icon(Icons.video_call_outlined),
                      const Padding(
                        padding: EdgeInsets.all(8.0),
                        child:Row(
                          children: [
                            Icon(Icons.mic_none_outlined),
                            Text("Audio Only"),
                          ],
                        ),
                      ),

                    ],
                    isSelected: obj.isSelected,
                    onPressed: (int index) {
                      if(index==2) {
                        obj.isSelect.value[index] = !obj.isSelect.value[index];
                        if(obj.isVideoSelected.value) {
                          obj.isSelect.value[1]=obj.isSelect.value[1];
                        } else {
                          obj.isSelect.value[1]=!obj.isSelect.value[1];
                        }

                      }
                      else{
                        if(obj.isSelect[2]) {
                          if(obj.isSelect[1]) {
                            obj.isSelect.value[1] = obj.isSelect.value[1];
                          }
                        } else {
                          if(index==1){
                            obj.isVideoSelected.value=!obj.isVideoSelected.value;
                          }
                          obj.isSelect.value[index] = !obj.isSelect.value[index];
                        }
                      }
                      obj.isSelect.refresh();
                    },
                    // region example 1
                    color: Colors.grey,
                    selectedColor: CustomColors.themeColor,
                    // endregion
                    // region example 2
                    borderColor: Colors.grey,
                    selectedBorderColor: CustomColors.themeColor,
                    constraints: BoxConstraints(
                        minHeight: 40, minWidth: MediaQuery.of(context).size.width/8),
                    // endregion
                  ),
                  GestureDetector(
                    onTap: (){
                      obj.settingListItem();
                      Get.to(() => SettingScreen(obj),
                          transition: Transition.leftToRight,
                          duration: const Duration(seconds: 1));
                    },
                    child: Container(
                        decoration: BoxDecoration(
                          border: Border.all(color: Colors.grey),),
                        child: const Padding(
                          padding: EdgeInsets.all(8.0),
                          child: Icon(Icons.settings_outlined),
                        )),
                  ),
                ],
              ),
              Padding(
                padding:  EdgeInsets.only(top:MediaQuery.of(context).size.height/10,left:MediaQuery.of(context).size.height/8,right: MediaQuery.of(context).size.height/8 ),
                child: Center(
                  child: DecoratedBox(
                    decoration: BoxDecoration(
                      gradient: const LinearGradient(
                          colors: [
                            Colors.pinkAccent,
                            Colors.pink,
                            CustomColors.themeColor,
                          ]),
                      borderRadius: BorderRadius.circular(15),),
                    child: ElevatedButton(
                      child: const Text("Join Now",style: TextStyle(color: Colors.white,fontWeight: FontWeight.w400,fontSize: 15),),
                      style: ElevatedButton.styleFrom(
                          backgroundColor: Colors.transparent,
                          disabledForegroundColor: Colors.transparent.withOpacity(0.38),
                          disabledBackgroundColor: Colors.transparent.withOpacity(0.12),
                          shadowColor: Colors.transparent,
                          elevation: 5,
                          shape:RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(15.0),) ,
                          fixedSize: Size(MediaQuery.of(context).size.width / 2, 50)),
                      onPressed: () {
                        obj.isConfirmation.value=true;
                        obj.configureRoom();
                      },
                    ),
                  ),
                ),
              ),],),
          )
          ],)

      ],
    ),
  );
}

==> enx_uikit_flutter-1.9.0.tar.gz: lib/widgets/confirmation_screen.dart <==
import 'dart:io';

import 'package:enx_flutter_plugin/enx_player_widget.dart';
import 'package:enx_uikit_flutter/screens/setting_ui.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:get/get.dart';
import 'package:get/get_core/src/get_main.dart';
import 'package:get/get_navigation/src/routes/transitions_type.dart';

import '../controller/enx_controller.dart';
import '../utilities/color.dart';

Widget confirmationScreen(context, EnxController obj) {
  return Container(
    color: Colors.white,
    child: Column(
      children: [
        Visibility(
          visible: false,
          child: AppBar(
            automaticallyImplyLeading: false,
            title: const Text('Video Preview',style: TextStyle(color: Colors.black,fontWeight: FontWeight.w500,fontSize: 17),),
            backgroundColor: Colors.white,
          ),
        ),
        MediaQuery.of(context).orientation==Orientation.portrait?
        Stack(
          alignment: Alignment.bottomCenter,
          children: [
            SizedBox(
          width: MediaQuery.of(context).size.width,
          height: MediaQuery.of(context).size.height-MediaQuery.of(context).size.height/17,
          child:obj.isSelected[1]||obj.isSelected[2]?Container(color: Colors.grey,child: const Icon(Icons.videocam_off_outlined),) :Platform.isAndroid
              ? EnxPlayerWidget(
            0,
            local: true,
            zMediaOverlay: false,
            height: MediaQuery.of(context).size.height ~/ 1.6,
          )
              : AspectRatio(
              aspectRatio: 3 / 2,
              child: EnxPlayerWidget(
                0,
                local: true,
                height: MediaQuery.of(context).size.height ~/ 1.6,
                width: MediaQuery.of(context).size.width.toInt(),
              )),
        ),
          Padding(
            padding: const EdgeInsets.all(12.0),
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(15.0),
              ),
            elevation: 15,
              child: Padding(
                padding: const EdgeInsets.only(left:20,top: 28.0,bottom: 28,right: 20),
                child: Wrap(
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        ToggleButtons(
                          children: <Widget>[
                            obj.isSelected.first?Icon(Icons.mic_off_outlined):Icon(Icons.mic_none_outlined),
                            obj.isSelected[1]? Icon(Icons.videocam_off_outlined):Icon(Icons.video_call_outlined),
                             const Padding(
                              padding: EdgeInsets.all(8.0),
                              child:Row(
                                children: [
                                  Icon(Icons.mic_none_outlined),
                                  Text("Audio Only"),
                                ],
                              ),
                            ),

                          ],
                          isSelected: obj.isSelected,
                          onPressed: (int index) {
                            if(index==2) {
                              obj.isSelect.value[index] = !obj.isSelect.value[index];
                              if(obj.isVideoSelected.value) {
                                obj.isSelect.value[1]=obj.isSelect.value[1];
                              } else {
                                obj.isSelect.value[1]=!obj.isSelect.value[1];
                              }

                            }
                            else{
                              if(obj.isSelect[2]) {
                                if(obj.isSelect[1]) {
                                  obj.isSelect.value[1] = obj.isSelect.value[1];
                                }
                              } else {
                                if(index==1){
                                  obj.isVideoSelected.value=!obj.isVideoSelected.value;
                                }
                                obj.isSelect.value[index] = !obj.isSelect.value[index];
                              }
                            }
                            obj.isSelect.refresh();
                          },
                          // region example 1
                          color: Colors.grey,
                          selectedColor: CustomColors.themeColor,
                          // endregion
                          // region example 2
                          borderColor: Colors.grey,
                          selectedBorderColor: CustomColors.themeColor,

                           constraints: BoxConstraints(
                              minHeight: 40, minWidth: MediaQuery.of(context).size.width/4),
                          // endregion
                        ),
                        // GestureDetector(
                        //   onTap: (){
                        //     obj.settingListItem();
                        //     Get.to(() => SettingScreen(obj),
                        //         transition: Transition.leftToRight,
                        //         duration: const Duration(seconds: 1));
                        //   // obj.isSetting.value=!obj.isSetting.value;
                        //     Fluttertoast.showToast(
                        //         msg: "Setting",
                        //         toastLength: Toast.LENGTH_SHORT,
                        //         gravity: ToastGravity.CENTER,
                        //         backgroundColor: Colors.red,
                        //         textColor: Colors.white,
                        //         fontSize: 16.0);
                        //   },
                        //   child: Container(
                        //     decoration: BoxDecoration(
                        //         border: Border.all(color: Colors.grey),),
                        //       child: const Padding(
                        //         padding: EdgeInsets.all(8.0),
                        //         child: Icon(Icons.settings_outlined),
                        //       )),
                        // ),
                      ],
                    ),
                   /* Padding(
                      padding:  EdgeInsets.only(left:MediaQuery.of(context).size.width/12,right: MediaQuery.of(context).size.width/10),
                      child: SwitchListTile( //switch at left side of label
                          value: obj.audioOnly,
                          controlAffinity: ListTileControlAffinity.trailing,
                          onChanged: (bool value){
                            obj.isAudioOnly.value=!obj.isAudioOnly.value;
                            obj.isAudioOnly.refresh();
                          },
                          title:  Text("Join as a audio call only",style: TextStyle(fontSize: 15,color: Colors.black,fontWeight: FontWeight.w400),)
                      ),
                    ),*/
                    Padding(
                      padding: const EdgeInsets.only(top:20.0),
                      child: Center(
                        child: DecoratedBox(
                         decoration: BoxDecoration(
                           gradient: const LinearGradient(
                                   colors: [
                                     Colors.pinkAccent,
                                     Colors.pink,
                                     CustomColors.themeColor,
                                     ]),
                            borderRadius: BorderRadius.circular(15),),
                          child: ElevatedButton(
                            child: const Text("Join Now",style: TextStyle(color: Colors.white,fontWeight: FontWeight.w400,fontSize: 15),),
                            style: ElevatedButton.styleFrom(
                                backgroundColor: Colors.transparent,
                                disabledForegroundColor: Colors.transparent.withOpacity(0.38),
                                disabledBackgroundColor: Colors.transparent.withOpacity(0.12),
                                shadowColor: Colors.transparent,
                                elevation: 5,
                                shape:RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(15.0),) ,
                                fixedSize: Size(MediaQuery.of(context).size.width / 2, 50)),
                            onPressed: () {
                              obj.isConfirmation.value=true;
                              obj.configureRoom();
                            },
                          ),
                        ),
                      ),
                    ),
                  ]
                ),
              ),
            ),
          ),
          ],):
          Row(
           crossAxisAlignment: CrossAxisAlignment.center,
            children:[
            SizedBox(
          width: MediaQuery.of(context).size.width/2,
          height: MediaQuery.of(context).size.height-35,
          child:obj.isSelected[1]||obj.isSelected[2]?Container(color: Colors.grey,child: const Icon(Icons.videocam_off_outlined),) :Platform.isAndroid
              ? EnxPlayerWidget(
            0,
            local: true,
            zMediaOverlay: false,
            height: MediaQuery.of(context).size.height ~/ 1.6,
          )
              : AspectRatio(
              aspectRatio: 3 / 2,
              child: EnxPlayerWidget(
                0,
                local: true,
                height: MediaQuery.of(context).size.height ~/ 1.6,
                width: MediaQuery.of(context).size.width.toInt(),
              )),
        ),
              SizedBox(
          width:MediaQuery.of(context).size.width/2,
            child: Wrap(
              alignment: WrapAlignment.center,
              children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  ToggleButtons(

                    children: <Widget>[
                      obj.isSelected.first?Icon(Icons.mic_off_outlined):Icon(Icons.mic_none_outlined),
                      obj.isSelected[1]? Icon(Icons.videocam_off_outlined):Icon(Icons.video_call_outlined),
                      const Padding(
                        padding: EdgeInsets.all(8.0),
                        child:Row(
                          children: [
                            Icon(Icons.mic_none_outlined),
                            Text("Audio Only"),
                          ],
                        ),
                      ),

                    ],
                    isSelected: obj.isSelected,
                    onPressed: (int index) {
                      if(index==2) {
                        obj.isSelect.value[index] = !obj.isSelect.value[index];
                        if(obj.isVideoSelected.value) {
                          obj.isSelect.value[1]=obj.isSelect.value[1];
                        } else {
                          obj.isSelect.value[1]=!obj.isSelect.value[1];
                        }

                      }
                      else{
                        if(obj.isSelect[2]) {
                          if(obj.isSelect[1]) {
                            obj.isSelect.value[1] = obj.isSelect.value[1];
                          }
                        } else {
                          if(index==1){
                            obj.isVideoSelected.value=!obj.isVideoSelected.value;
                          }
                          obj.isSelect.value[index] = !obj.isSelect.value[index];
                        }
                      }
                      obj.isSelect.refresh();
                    },
                    // region example 1
                    color: Colors.grey,
                    selectedColor: CustomColors.themeColor,
                    // endregion
                    // region example 2
                    borderColor: Colors.grey,
                    selectedBorderColor: CustomColors.themeColor,
                    constraints: BoxConstraints(
                        minHeight: 40, minWidth: MediaQuery.of(context).size.width/8),
                    // endregion
                  ),
                  GestureDetector(
                    onTap: (){
                      obj.settingListItem();
                      Get.to(() => SettingScreen(obj),
                          transition: Transition.leftToRight,
                          duration: const Duration(seconds: 1));
                    },
                    child: Container(
                        decoration: BoxDecoration(
                          border: Border.all(color: Colors.grey),),
                        child: const Padding(
                          padding: EdgeInsets.all(8.0),
                          child: Icon(Icons.settings_outlined),
                        )),
                  ),
                ],
              ),
              Padding(
                padding:  EdgeInsets.only(top:MediaQuery.of(context).size.height/10,left:MediaQuery.of(context).size.height/8,right: MediaQuery.of(context).size.height/8 ),
                child: Center(
                  child: DecoratedBox(
                    decoration: BoxDecoration(
                      gradient: const LinearGradient(
                          colors: [
                            Colors.pinkAccent,
                            Colors.pink,
                            CustomColors.themeColor,
                          ]),
                      borderRadius: BorderRadius.circular(15),),
                    child: ElevatedButton(
                      child: const Text("Join Now",style: TextStyle(color: Colors.white,fontWeight: FontWeight.w400,fontSize: 15),),
                      style: ElevatedButton.styleFrom(
                          backgroundColor: Colors.transparent,
                          disabledForegroundColor: Colors.transparent.withOpacity(0.38),
                          disabledBackgroundColor: Colors.transparent.withOpacity(0.12),
                          shadowColor: Colors.transparent,
                          elevation: 5,
                          shape:RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(15.0),) ,
                          fixedSize: Size(MediaQuery.of(context).size.width / 2, 50)),
                      onPressed: () {
                        obj.isConfirmation.value=true;
                        obj.configureRoom();
                      },
                    ),
                  ),
                ),
              ),],),
          )
          ],)

      ],
    ),
  );
}
